import { WebPlugin } from '@capacitor/core';
export class JWPlayerWeb extends WebPlugin {
    constructor() {
        super(...arguments);
        this.playerInstance = undefined;
    }
    async echo(options) {
        return options;
    }
    async initialize(options) {
        if (options.webLicenseKey) {
            jwplayer.key = options.webLicenseKey;
            jwplayer.debug = options.debug;
            window.screen.orientation.lock('landscape');
        }
        else {
            console.error('Jwplayer does not have a key', options);
        }
    }
    async remove() {
        if (this.playerInstance) {
            await this.playerInstance.remove();
            this.playerInstance = undefined;
            window.screen.orientation.lock('portrait');
        }
        return true;
    }
    async create(options) {
        var _a;
        if (options.webConfiguration) {
            this.playerInstance = jwplayer(options.webConfiguration.container);
            const config = Object.assign({}, (_a = options.webConfiguration.properties) !== null && _a !== void 0 ? _a : {});
            if (options.advertisingConfig && options.advertisingConfig.schedule) {
                const timestamp = Math.floor(Date.now() / 1000);
                config.advertising = {
                    client: options.advertisingConfig.type == 'vast' ? 'vast' : 'googima',
                    adscheduleid: '' + timestamp,
                    schedule: options.advertisingConfig.schedule.map(c => {
                        return {
                            offset: c.begin, tag: c.url
                        };
                    })
                };
            }
            this.playerInstance.setup(config);
            this.loadEvents();
        }
    }
    loadEvents() {
        this.playerInstance.on('ready', (eventData) => {
            const event = {
                name: 'readyPlayerEvent',
                data: eventData
            };
            this.notifyListeners('readyPlayerEvent', event);
        });
        this.playerInstance.on('fullscreen', (eventData) => {
            const event = {
                name: 'fullScreenPlayerEvent',
                data: eventData
            };
            this.notifyListeners('fullScreenPlayerEvent', event);
        });
        this.playerInstance.on('play', (eventData) => {
            const event = {
                name: 'play',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('pause', (eventData) => {
            const event = {
                name: 'pause',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('playAttemptFailed', (eventData) => {
            const event = {
                name: 'playAttemptFailed',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('buffer', (eventData) => {
            const event = {
                name: 'buffer',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('idle', (eventData) => {
            const event = {
                name: 'idle',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('complete', (eventData) => {
            const event = {
                name: 'complete',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('error', (eventData) => {
            const event = {
                name: 'error',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('warning', (eventData) => {
            const event = {
                name: 'warning',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('seek', (eventData) => {
            const event = {
                name: 'seek',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('time', (eventData) => {
            const event = {
                name: 'time',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('playlistItem', (eventData) => {
            const event = {
                name: 'playlistItem',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('playlistComplete', (eventData) => {
            const event = {
                name: 'playlistComplete',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
        this.playerInstance.on('firstFrame', (eventData) => {
            const event = {
                name: 'firstFrame',
                data: eventData
            };
            this.notifyListeners('playerEvent', event);
        });
    }
    getPosition() {
        if (this.playerInstance !== undefined) {
            return Promise.resolve({ value: this.playerInstance.getPosition() });
        }
        return Promise.resolve({ value: 0 });
    }
    seek(options) {
        this.playerInstance.seek(options.position);
        return Promise.resolve(true);
    }
    addCuePoints(options) {
        this.playerInstance.addCues(options.cuePoints);
    }
    addButton(img, tooltip, callback, id, btnClass) {
        this.playerInstance.addButton(img, tooltip, callback, id, btnClass);
    }
    playlistItem(options) {
        this.playerInstance.playlistItem(options.index);
        return Promise.resolve(true);
    }
}
//# sourceMappingURL=web.js.map